@@ -357,7 +357,7 @@ class FPLAnalytics:
                 teams = self.calcNewRatings(teams, current_gw_info)
         return teams
     
-    def comparePlayers(self, player1, player2, features = None):
+    def comparePlayers(self, player1, player2, features = None, filename = None):
         if features is None:
             features = ['pgxG90',
                         'pg90',
@@ -404,5 +404,7 @@ class FPLAnalytics:
             ax.fill(angles, values, 'r', alpha=0.1)
 
             plt.legend(loc='upper right', bbox_to_anchor=(0.1, 0.1))
+            if filename:
+                plt.savefig(filename + '.png')
         
         return players
